# CHTS2012Bike_Walk_Transit_Ratio2016-03-12.R  N Maizlish  3/12/2016
# Reads CHTS2011 trip file and calculates time and distance of bike and 
# and walk associated-transit trips and creates ratios with respect to
# total transit distance (AT and non-AT related transit trips)

# set working directory
setwd ('C:/SASUniversityEdition/myfolders/ITHIM/TravelSurveys/CalTRANS/CHTS2012')
# Get todays date to assign version
# today <- Sys.Date()
today <- date()

# turn off scientific notation
options(scipen=999)

# Read county FIPS file
county_fips <-read.csv(file= "CA_County_FIPS2Region2010.csv", head=TRUE, sep=",")
# Rename county FIPS code
names(county_fips)[names(county_fips)=="county_fips"] <-"county_id"
county_fips <- county_fips[, c("county_id","countyname","megaregion_name","megaregion_code")]

# create 3-digit county identifier
county_fips$county_id = county_fips$county_id - 6000


########################### Trip File #####################
trip <- read.csv(file= "trip_cleaned2016-03-26.csv", head=TRUE, sep=",", na.strings=c("NA"))

# Subset bus (6) and rail (8) trips
transit <- subset(trip, mode_code==6 | mode_code==8)

# Merge to pick up megaregion
transit <- merge(transit,county_fips, by="county_id", all.x=TRUE)

transit <- transit[,c("sampno", "perno", "tripno","county_id", "megaregion_name", "megaregion_code", "mode_name", "mode_code", "new_trip_distance_miles", "tripdur")]
nrow(transit)

# Examine previous trip
# keep variables of interest
pretrip <- transit[,c("sampno", "perno", "tripno")]
pretrip$tripno <- pretrip$tripno - 1
                   
# merge back to original trip file to pick up trip prior to transit trip
 priortrip <-merge(trip,pretrip, by=c("sampno", "perno","tripno"))

# subset bike (2) and walk (1) trips associated with transit
priortrip <- subset(priortrip, mode_code==1 | mode_code==2)

# reset trip number for merge to transit trip file
priortrip$tripno <- priortrip$tripno + 1

# Save and rename variables
names(priortrip)[names(priortrip)=="mode_name"] <-"pre_mode_name"
names(priortrip)[names(priortrip)=="new_trip_distance_miles"] <- "pre_trip_distance_miles"
names(priortrip)[names(priortrip)=="tripdur"] <- "pre_tripdur"
priortrip <- priortrip[,c("sampno", "perno", "tripno", "pre_mode_name", "pre_trip_distance_miles", "pre_tripdur")]

# Examine subsequent trip
# keep variables of interest
posttrip <- transit[,c("sampno", "perno", "tripno")]
posttrip$tripno <- posttrip$tripno + 1
                   
# merge back to original trip file to pick up subsequent transit trip
subsequenttrip <-merge(trip,posttrip, by=c("sampno", "perno","tripno"))

#subset bike and walk trips associated with transit
subsequenttrip <- subset(subsequenttrip, mode_code==1 | mode_code==2)

# reset trip number for merge to transit trip file
subsequenttrip$tripno <- subsequenttrip$tripno - 1

# Save and rename variables
names(subsequenttrip)[names(subsequenttrip)=="mode_name"] <-"post_mode_name"
names(subsequenttrip)[names(subsequenttrip)=="new_trip_distance_miles"] <- "post_trip_distance_miles"
names(subsequenttrip)[names(subsequenttrip)=="tripdur"] <- "post_tripdur"

subsequenttrip <- subsequenttrip[,c("sampno", "perno", "tripno", "post_mode_name", "post_trip_distance_miles", "post_tripdur")]


#### Merge files back to transit trip
transit <-merge(transit,priortrip, by=c("sampno", "perno","tripno"), all.x = TRUE)

transit <-merge(transit,subsequenttrip, by=c("sampno", "perno","tripno"), all.x = TRUE)

# Set missing distances and times to 0 
transit$pre_trip_distance_miles[is.na(transit$pre_trip_distance_miles)] <- 0
transit$pre_tripdur[is.na(transit$pre_tripdur)] <- 0
transit$post_trip_distance_miles[is.na(transit$post_trip_distance_miles)] <- 0
transit$post_tripdur[is.na(transit$post_tripdur)] <- 0

# if there are any partial trips from bus-rail chaining
# make phantom half of trip (0 miles) same other half
transit$at_mode_name <- NULL
transit$at_mode_name[transit$pre_mode_name=="Walk" | transit$post_mode_name=="Walk"] <- "Walk"
transit$at_mode_name[transit$pre_mode_name=="Bike" | transit$post_mode_name=="Bike"] <- "Bike"

# Sum AT distance and minutes from pre and post transit trip
transit$at_trip_distance_miles <- transit$pre_trip_distance_miles + transit$post_trip_distance_miles
transit$at_tripdur <- transit$pre_tripdur + transit$post_tripdur


# Calculate the ratio of bike/walk AT to transit
# Distances

at_dist_mode_reg <- as.data.frame(aggregate(transit$at_trip_distance_miles~transit$at_mode_name+transit$mode_name+transit$megaregion_name,FUN="sum"))
transit_dist_mode_reg <- as.data.frame(aggregate(transit$new_trip_distance_miles~transit$mode_name+transit$megaregion_name,FUN="sum"))


dist_ratio <- merge(at_dist_mode_reg,transit_dist_mode_reg, by=c("transit$mode_name", "transit$megaregion_name"), all.x=TRUE)
dist_ratio$ratio <- dist_ratio[,4]/dist_ratio[,5]

# Times
at_time_mode_reg <- as.data.frame(aggregate(transit$at_tripdur~transit$at_mode_name+transit$mode_name+transit$megaregion_name,FUN="sum"))
transit_time_mode_reg <- as.data.frame(aggregate(transit$tripdur~transit$mode_name+transit$megaregion_name,FUN="sum"))

time_ratio <- merge(at_time_mode_reg,transit_time_mode_reg, by=c("transit$mode_name","transit$megaregion_name"), all.x=TRUE)
time_ratio$ratio <- time_ratio[,4]/time_ratio[,5]

# Write time ratio file
write.csv(time_ratio, paste0("at_transit_time_ratio",format(Sys.time(), "%Y-%m-%d"), ".csv"), row.names=FALSE)

