* CHIS2009_PA_Quintiles_SD8-30-13confidential.sas  Neil Maizlish;
* Purpose: to calculate distribution of time of non-transport ;
* physical activity per week by sex and age categories; 
* Non-travel activity time = non-travel walk + work + moderate;
* exercise + vigorous exercise AND the SD of transport-rtealted;
* Travel time to provide a weekly rather than daily estimate;
* Based on travel surveys;
* MET-hours per week is based on METS for main occupational titles ;
* for workers and non-work activities for non-workers;

* read in CHIS County to MPO Lookup Table;
proc import datafile='C:\CHIS\CHIS_USERS\NEIL MAIZLISH\Physical Activity\CA_CHIS_lookup.xls' dbms=xls out= CA_CHIS_lookup replace;
getnames=yes;
run;
proc sort; by REGION41;run;

* read MPO Bike:walk ratio table;
proc import datafile='C:\CHIS\CHIS_USERS\NEIL MAIZLISH\Physical Activity\BikeWalkRationAgeSexMPO.xls' dbms=EXCEL out=bike2walk_ratio replace;
getnames=yes;
sheet="Bike2Walk";
run;

data bike2walk_ratio (keep = mpo_region_code geotype_code srsex age8cat bike2walkratio); 
  set bike2walk_ratio;

* recode gender;
if gender = "M" then srsex = 1;
if gender = "F" then srsex = 2;

* recode age categories;
age8cat = 1;
if age_group = "05-14" then age8cat = 2;
if age_group = "15-29" then age8cat = 3;
if age_group = "30-44" then age8cat = 4;
if age_group = "45-59" then age8cat = 5;
if age_group = "60-69" then age8cat = 6;
if age_group = "70-79" then age8cat = 7;
if age_group = "80+" then age8cat = 8;

* recode MPOs;
if geotype_code = "Bay Area" then mpo_region_code = "01";
if geotype_code = "Butte" then mpo_region_code = "02";
if geotype_code = "Central/Southeast Sierra" then mpo_region_code = "03";
if geotype_code = "Monterey Bay" then mpo_region_code = "04"  ;
if geotype_code = "North Coast" then mpo_region_code = "05";
if geotype_code = "Northeast Sierra" then mpo_region_code = "06";
if geotype_code = "Northern Sacramento Valley" then mpo_region_code = "07";
if geotype_code = "Sacramento Area" then mpo_region_code = "08";
if geotype_code = "San Diego" then mpo_region_code = "09";
if geotype_code = "San Joaquin Valley" then mpo_region_code = "10";
if geotype_code = "San Luis Obispo" then mpo_region_code = "11";
if geotype_code = "Santa Barbara" then mpo_region_code = "12";
if geotype_code = "Shasta" then mpo_region_code = "13";
if geotype_code = "Southern California" then mpo_region_code = "14";

run;
proc sort; by mpo_region_code srsex age8cat; run;

* Create library;
libname chis 'C:\CHIS\CHIS 2009\Adult';
filename chis 'C:\CHIS\CHIS 2009\Adult';
data adult; 
  set chis.adult;

* create CHIS county random dummy variable for public use file testing;
* Actual variable is numeric and called is REGION41;
* CHIS_code_n = uniform(-1);
* CHIS_code_n = int(CHIS_code_n*41)+1;
* Chis_code = put(chis_code_n, z2.);

* Create age categories;
if srage_p = . then age8cat=.;
if  srage_p <=4 then age8cat = 1;
if (srage_p >=5  AND srage_p <=14) then age8cat = 2;
if (srage_p >=15 AND srage_p <=29) then age8cat = 3;
if (srage_p >=30 AND srage_p <=44) then age8cat = 4;
if (srage_p >=45 AND srage_p <=59) then age8cat = 5;
if (srage_p >=60 AND srage_p <=69) then age8cat = 6;
if (srage_p >=70 AND srage_p <=79) then age8cat = 7;
if (srage_p >=80) then age8cat = 8;
run;
proc sort; by REGION41; run;
proc contents;run;

* Merge with CHIS code file to assign mpo_region_code;
data adult;
 merge adult CA_CHIS_lookup;
by REGION41;
run;
proc sort; by mpo_region_code srsex age8cat; run;


* Merge with bike walk ratio;
data adult;
 merge adult bike2walk_ratio;
 by mpo_region_code srsex age8cat;

* Create walk for fun, job-related, moderate and vigorous phys activity;

* Walk for fun;
minwk_walk4fun=.;
minwk_walk4fun = ad42w;
if ad40w = -1 or ad40w = 2 then minwk_walk4fun=0;
if ad42wunt=2 then minwk_walk4fun=minwk_walk4fun*60;
minday_walk4fun = minwk_walk4fun;
minwk_walk4fun=minwk_walk4fun*ad41w;

* Percent of the population walking for transport;
walk4transport = ad37w;
minwk_walk4transport=.;
minwk_walk4transport = ad39w;
if ad37w = 2 or ad37w = 3 then minwk_walk4transport=0;
if ad39wunt=2 then minwk_walk4transport=minwk_walk4transport*60;
minday_walk4transport = minwk_walk4transport ;
minwk_walk4transport=minwk_walk4transport*ad38w;

* Estimate minutes/day and week bicycle from BATS2000 data on ratio;
* of walk time to bike time stratified by age and sex;

* Total walking;
* Per day  used to estimate CV based on daily vs. weekly surveys;
minday_walk = 0;
minday_walk = minday_walk4transport + minday_walk4fun;
if minday_walk = . then minday_walk = 0; 

minday_bike =0;
minday_bike = minday_walk*bike2walkratio;
if minday_bike = . then minday_bike = 0;

* per week;
minwk_walk = 0;
minwk_walk = minwk_walk4transport + minwk_walk4fun; 
if minwk_walk = . then minwk_walk = 0;

minwk_bike =0;
minwk_bike = minwk_walk*bike2walkratio;
if minwk_bike = . then minwk_bike = 0;

* Transport-Related METS;
if age8cat < 6 then MET_transport_hrs_wk = 3.8*(minwk_walk/60)+ 3.8*(minwk_bike/60);
if age8cat = 6 then MET_transport_hrs_wk = 3.0*(minwk_walk/60)+ 3.8*(minwk_bike/60);
if age8cat = 7 then MET_transport_hrs_wk = 2.5*(minwk_walk/60)+ 3.8*(minwk_bike/60);
if age8cat = 8 then MET_transport_hrs_wk = 2.5*(minwk_walk/60)+ 3.8*(minwk_bike/60);

* Transport-Related Hours per week;
if age8cat < 6 then transport_hrs_wk = (minwk_walk/60)+ (minwk_bike/60);
if age8cat = 6 then transport_hrs_wk = (minwk_walk/60)+ (minwk_bike/60);
if age8cat = 7 then transport_hrs_wk = (minwk_walk/60)+ (minwk_bike/60);
if age8cat = 8 then transport_hrs_wk = (minwk_walk/60)+ (minwk_bike/60);

* Transport-Related Hours per day;
transport_min_day = minday_walk + minday_bike;

* Moderate Physical Activity;
minwk_mod=.;
minwk_mod=ae27a;
if ae26=-1 then minwk_mod=0;
if ae27 le 0 then minwk_mod=0;
if ae27aunt=2 then minwk_mod=minwk_mod*60;
minwk_mod=minwk_mod*ae27;

* Vigorous Activity;
minwk_vig=.;
minwk_vig=ae25a;
if ae24=-1 then minwk_vig=0;
if ae25 le 0 then minwk_vig=0;
if ae25aunt=2 then minwk_vig=minwk_vig*60;
minwk_vig=minwk_vig*ae25;

* Make MET assignments;
* Walking for fun;
if age8cat < 6 then MET_walk_hrs_wk = 3.8*(minwk_walk4fun/60);
if age8cat = 6 then MET_walk_hrs_wk = 3.0*(minwk_walk4fun/60);
if age8cat = 7 then MET_walk_hrs_wk = 2.5*(minwk_walk4fun/60);
if age8cat = 8 then MET_walk_hrs_wk = 2.5*(minwk_walk4fun/60);

* Moderate exercise;
if age8cat < 6 then MET_mod_hrs_wk = 3.8*(minwk_mod/60);
if age8cat = 6 then MET_mod_hrs_wk = 3.0*(minwk_mod/60);
if age8cat = 7 then MET_mod_hrs_wk = 2.5*(minwk_mod/60);
if age8cat = 8 then MET_mod_hrs_wk = 2.5*(minwk_mod/60);   

* Vigorous exercise;
if age8cat < 6 then MET_vig_hrs_wk = 9.0*(minwk_vig/60);
if age8cat = 6 then MET_vig_hrs_wk = 8.0*(minwk_vig/60);
if age8cat = 7 then MET_vig_hrs_wk = 7.0*(minwk_vig/60);
if age8cat = 8 then MET_vig_hrs_wk = 6.0*(minwk_vig/60);   

* Occupational physical activity for people <60 years of age;
* management, professional, office;

* Asterisk out next line to set minimum day time activity hours;
* On-job physical activity;
* AK3 is hours worked. Assumption that non-job PA is 0 METS;

* Initialize hours worked and non-job activity for unemployed;
hours_worked = 0 ;
if ak3 > 0 then hours_worked = ak3;

* Use Woodcock's rule that 5 of 8 hours/day of work are at the;
* nominal MET rating; 
hours_worked = (5/8)*hours_worked;

* CHIS 2009 Does not have occupational information;
* General estimate is 1.64 METS * hours worked;
* this is based on the occupation weighted average from 2005 CHIS;
* See files Data2005\CHIS2005_Physical_Activity_Quintiles7-12-11.sas and;
* CHIS\Data2009\Occupation-weighted_METave42009CHIS8-30-13.xls;
MET_occ_hrs_wk = 0;
MET_occ_hrs_wk = 1.64*hours_worked;

* Total  non transport related physical activity;
* Inclusion of walking is double counting;

MET_hrwk_nt_pa = MET_mod_hrs_wk + MET_vig_hrs_wk + MET_occ_hrs_wk;
run; 
proc sort; by megaregion_code age8cat srsex; run;


* Create decile groups;
proc rank groups=5 out=transport_quintiles ties=mean descending;
by megaregion_code age8cat srsex;
var MET_transport_hrs_wk;
ranks transport_pa5;


********************************** End of Data Step*******************;
run;


********************************** Beginning of Proc Steps ***********;
* proc freq;
*  tables age8cat MET_transport_hrs_wk MET_hrwk_nt_pa walk4transport ;
*  weight rakedw0;
* run;

proc sort;
by megaregion_code srsex age8cat transport_pa5;
run;

* Calculate Median of quintiles;
proc means NOPRINT;
    by megaregion_code srsex age8cat transport_pa5;
    var MET_hrwk_nt_pa;
    weight rakedw0;
    output out=nt_pa_METS MEDIAN(MET_hrwk_nt_pa) = ntMETS;
run;


* Restrict to adult age groups;
data nt_pa_METS;
 set nt_pa_METS;
 if age8cat > 2;
run;

proc sort;
 by megaregion_code srsex age8cat DESCENDING transport_pa5;
run;


proc print;
title 'Median Non-Travel METS of Walking+Biking MET Quintiles, CHIS Adult, 2009'; 
run;

data transport_hrs;
  set adult (KEEP = megaregion_code REGION41 rakedw0 transport_hrs_wk transport_min_day);
run;

PROC SURVEYMEANS mean median;
STRATA megaregion_code ;
VAR transport_hrs_wk transport_min_day;
WEIGHT rakedw0 ;
run;

* proc export data=transport_hrs outfile= 'H:\CHIS\Data2009\mydata2009.csv' replace;
* run;

********* Calculation of standard deviation and coefficient of variation;

%macro loop1(relist);
%local i regroup;
%let i=1;
%let regroup=%scan(&relist,&i);
%do %while (&regroup ne);

* Mega Region 1;
data transport_hrs&i;
set transport_hrs;
if megaregion_code = "&regroup";
run;

proc surveymeans data= transport_hrs&i mean stacking ;
   weight rakedw0;
   strata REGION41;
*  cluster Person_id;      
   var transport_hrs_wk;
   ods output Statistics = Statistics 
              Summary = Summary;
run;  
data _null_;
   set Statistics;
   call symput("transport_hrs_wk_mean", transport_hrs_wk_Mean);
run;
data Summary;
   set Summary;
   if Label1="Sum of Weights" then call symput("N",cValue1);
   if Label1="Number of Strata" then call symput("H",cValue1);
   if Label1="Number of Clusters" then call symput("C",cValue1);
run;

data Working;
   set transport_hrs&i;
   z=(1/(&N-1))*(transport_hrs_wk-&transport_hrs_wk_Mean)**2;
run;
proc surveymeans data = Working sum stacking;
   weight rakedw0;
   var z;
   ods output Statistics = Result;
run;   

data Result&i;
   set Result;
   StdDev=sqrt(z_Sum);
   call symput("Variance",z_Sum);
   call symput("StdDev",StdDev);
   cv = StdDev/&transport_hrs_wk_Mean;
   mean = &transport_hrs_wk_Mean; 
   megaregion_code ="&regroup";
run;

proc contents;run;

%let i=%eval(&i+1);
%let regroup=%scan(&relist,&i);
%end;
%mend loop1;
%loop1(01 02 03 04 05 06 07);


* Concatenate the data files for mega-regions;

data transport_hrs_sd;
  set result1 result2 result3 result4 result5 result6 result7;
run;
proc contents; run;

*/
