* Item5CA2010_County_age-sex_pop5-8-13.sas  N Maizlish 5/10/13 ;
* Reads 2010 QTP1 (SF1) file and reformats age-sex population counts;
* in 16 cell ITHIM format for the construction of age-sex specific;
* population proportions by California County, 2010;


* Read Region Look-up Table;
proc import datafile= 'T:\ITHIM\Crosswalks\CA_mpo2010.xls' dbms=xls out= CA_mpo2010 replace;
getnames=yes;
run;

proc import datafile= 'T:\ITHIM\Crosswalks\CA_megaregion2010.xls' dbms=xls out= CA_MegaRegion2010 replace;
getnames=yes;
run;


proc sort; by megaregion_code;run;

* Read County to Region Look-up Table;
proc import datafile= 'T:\ITHIM\Crosswalks\CA_County_FIPS2Region2010.xlsx' dbms=xlsx out= CA_County_FIPS2Region2010 replace;
getnames=yes;
run;

proc sort; by county_fips;run;


* Read 2010 Census file;
proc import datafile= 'T:\ITHIM\OtherData\2010Census\DEC_10_SF1_QTP1.csv' dbms=dlm out=ca_co_age_sex_wide replace;
delimiter=",";
getnames=yes;
guessingrows=500;
datarow = 3;
run;

* Aggregate the Census data into age sex bins as comparable with the Oberg study;
data ca_co_age_sex_wide;
  set ca_co_age_sex_wide;

m00 = SUBHD0102_S02;
m05 = SUBHD0102_S03 + SUBHD0102_S04;
m15 = SUBHD0102_S05 + SUBHD0102_S06 + SUBHD0102_S07;
m30 = SUBHD0102_S08 + SUBHD0102_S09 + SUBHD0102_S10;
m45 = SUBHD0102_S11 + SUBHD0102_S12 + SUBHD0102_S13;
m60 = SUBHD0102_S14 + SUBHD0102_S15;
m70 = SUBHD0102_S16 + SUBHD0102_S17;
m80 = SUBHD0102_S18 + SUBHD0102_S19 + SUBHD0102_S20;

f00 = SUBHD0103_S02;
f05 = SUBHD0103_S03 + SUBHD0103_S04;
f15 = SUBHD0103_S05 + SUBHD0103_S06 + SUBHD0103_S07;
f30 = SUBHD0103_S08 + SUBHD0103_S09 + SUBHD0103_S10;
f45 = SUBHD0103_S11 + SUBHD0103_S12 + SUBHD0103_S13;
f60 = SUBHD0103_S14 + SUBHD0103_S15;
f70 = SUBHD0103_S16 + SUBHD0103_S17;
f80 = SUBHD0103_S18 + SUBHD0103_S19 + SUBHD0103_S20;


run;

* Save total population in file for denominator of proportion; 
* Note:  For this example the "universe" is all male/females who are older than 10; 
data co_total_pop;
  set ca_co_age_sex_wide (keep = geo_id SUBHD0101_S01);
run;


*********** Total population by county;
data co_total_pop;
  set co_total_pop (rename = (geo_id = county_fips SUBHD0101_S01 = totalpop));;
county_fips = substr(county_fips,10,5);
run;
proc sort;by county_fips;run;


* Transpose age-sex file;
proc transpose data= ca_co_age_sex_wide out= ca_co_age_sex_long;
var m00 m05 m15 m30 m45 m60 m70 m80 f00 f05 f15 f30 f45 f60 f70 f80;
by geo_id;
run;

* Rename variables;
data ca_co_age_sex;
 set ca_co_age_sex_long (rename = (_name_=sexage col1=pop));
county_fips = substr(geo_id,10,5);
if substr(sexage,1,1)= "m" then sex = "m";
if substr(sexage,1,1)= "f" then sex = "f";
age_group_char = substr(sexage,2,2);
*age_group =input(age_group_char,2.0);
if age_group_char=0 then age_group = '00-04';
if age_group_char=5 then age_group = '05-14';
if age_group_char=15 then age_group = '15-29';
if age_group_char=30 then age_group = '30-44';
if age_group_char=45 then age_group = '45-59';
if age_group_char=60 then age_group = '60-69';
if age_group_char=70 then age_group = '70-79';
if age_group_char=80 then age_group = '80+';
run;

* Drop and reorder variables;
data ca_co_age_sex (drop = geo_id sexage age_group_char); 
 retain county_fips sex age_group pop;
set ca_co_age_sex;
run;

proc sort; by county_fips;run;

* merge with county-region look-up table;
data ca_co_age_sex;
merge ca_co_age_sex co_total_pop CA_County_FIPS2Region2010;
by county_fips ;
run;

* Calculate the age-sex proportion;
data ca_co_age_sex (rename = (countyname = geotype_name));
set ca_co_age_sex;
item_result = pop/totalpop;
geotype="county";
unwt_N = pop;
run;

proc sort data=ca_co_age_sex; by mpo_code sex age_group;run;


**************** Regional Aggregation **********************;
******************************** 14 MPO Regions -- REGION***;
* Aggregate Age-sex cells by Region;
proc means data= ca_co_age_sex noprint;
 by mpo_code sex age_group;
 var pop;
output out = ca_mpo_age_sex_pop  SUM(pop) = pop2010;
run;

proc sort; by mpo_code;run;

* merge back to pick up region name;
data ca_mpo_age_sex_pop (DROP = _Type_ _freq_);
 format mpo_name $CHAR30.;
 merge ca_mpo_age_sex_pop CA_mpo2010;
 by mpo_code;
run; 
  
proc sort; by mpo_code;run;

* merge total pop file with regions;
data ca_region_total_pop;
merge co_total_pop CA_County_FIPS2Region2010;
by county_fips ;
run;

proc sort; by mpo_code;run;

***************** Aggregate total population by Region;
proc means data= ca_region_total_pop noprint;
 by mpo_code;
 var totalpop;
output out = ca_region_total_pop  SUM(totalpop) = totalpop2010;
run;

proc sort; by mpo_code;run;

*** Merge age-sex regional files total pop file;
data ca_mpo_age_sex_pop (DROP = _Type_ _freq_);
  merge ca_mpo_age_sex_pop ca_region_total_pop;
by mpo_code;
run;

data ca_mpo_age_sex_pop (rename = (pop2010=unwt_N mpo_name=geotype_name mpo_code=geotype_code));
  set ca_mpo_age_sex_pop;
   item_result = pop2010/totalpop2010;
geotype = "MPO";
run;


******************************** 7 MegaRegions -- Megaregion***;
* Aggregate Age-sex cells by Region;
proc sort data=ca_co_age_sex; by megaregion_code sex age_group;run;
proc means data= ca_co_age_sex noprint;
 by megaregion_code sex age_group;
 var pop;
output out = ca_megaregion_age_sex_pop  SUM(pop) = pop2010;
run;

proc sort; by megaregion_code;run;

* merge back to pick up region name;
data ca_megaregion_age_sex_pop (DROP = _Type_ _freq_);
 merge ca_megaregion_age_sex_pop ca_megaregion2010;
 by megaregion_code;
run; 
  
proc sort; by megaregion_code;run;

* merge total pop file with regions;
data ca_megaregion_total_pop;
merge co_total_pop CA_County_FIPS2Region2010;
by county_fips ;
run;

proc sort; by megaregion_code;run;
***************** Aggregate total population by Region;
proc means data= ca_megaregion_total_pop noprint;
 by megaregion_code;
 var totalpop;
output out = ca_megaregion_total_pop  SUM(totalpop) = totalpop2010;
run;

proc sort; by megaregion_code;run;

*** Merge age-sex regional files total pop file;
data ca_megaregion_age_sex_pop (DROP = _Type_ _freq_);
  merge ca_megaregion_age_sex_pop ca_megaregion_total_pop;
by megaregion_code;
run;

data ca_megaregion_age_sex_pop (rename = (pop2010=unwt_N mpo_name=geotype_name));
 set ca_megaregion_age_sex_pop;
   item_result = pop2010/totalpop2010;
geotype = "megaregion";
run;


data ca_megaregion_age_sex_pop (rename = (megaregion_name=geotype_name Megaregion_code=geotype_code));
set ca_megaregion_age_sex_pop;
run;





* Combine regions and county files;
data item5 (rename = (county_fips=geotype_code));
set ca_co_age_sex;
run;


data item5 (drop = totalpop2010 mpo_name mpo_code pop totalpop megaregion_name megaregion_code region_name region_code);
format geotype $CHAR11. geotype_name $CHAR26.;
 set item5 ca_mpo_age_sex_pop ca_megaregion_age_sex_pop;
run;

data item5;
retain scenario_id item_id item_name units urbrur report_year geotype geotype_name geotype_code county_fips mode mode_code age_group sex strata_type strata unwt_n wt_N item_result se cv date;
 set item5 ;
 scenario_id = 1;
 item_id = 5;
 Item_name  = "Distribution of population by age and gender";
 units = "percent";
 urbrur = 0;
 report_year = "2010";
 mode ="";
 mode_code =0;
 strata_type="-";
 strata="-";
 wt_N = .;
 se =.;
 cv =.;
 date = DATETIME();
 format date datetime16.0; 
run;

data item5;
retain scenario_id item_id item_name units urbrur report_year geotype geotype_name geotype_code county_fips mode mode_code age_group sex strata_type strata unwt_n wt_N item_result se cv date;
set item5 ;
run;



proc contents; run;

* Export County file as CSV file;
proc export data= item5 outfile='T:\ITHIM\CalibrationData\Item5_DistrOfPopByAgeGender\ITHIM_item5pop_age_sex2010.csv' dbms=CSV replace;
run;

* Export County file as xlsx file;
proc export data= item5 outfile='T:\ITHIM\CalibrationData\Item5_DistrOfPopByAgeGender\ITHIM_item5pop_age_sex2010.xls' dbms=xls replace;
run;