* Item13Victim_Striking_inj_matrix2011-2015.sas - N Maizlish - 8/3/19 ;
* Matrix of number of injuries by striking and struck victim;
* The source of the road traffic injury data is SWITRS publically;
* available by UC Berkeley SafeTREC TIMS http://www.tims.berkeley.edu/;
* This analysis is restricted to fatal and serious injuries between;
* the years 2011 and 2015, which sync with a baseline year of ~2010;


* Create a collision file in which all parties are on each victim row;
* and Parties are identified as striking vehicle or not;

* comment out this section PART 1 until loop1; 
*******  Read Collisions Datafile *******;
proc import datafile= '/folders/myfolders/myfolders/ITHIM/CalibrationData/Item13_CollisionsBetStrikingVehVicVeh/collisions.csv' dbms=csv out=collisions replace;
getnames=yes;
run;

* Subset years;
data collisions; 
 set collisions (where=(year GE 2011 and year LE 2015));
run; 
proc sort; by caseid;run;
proc contents; run;

*******  Read Parties Datafile *******;
proc import datafile= '/folders/myfolders/myfolders/ITHIM/CalibrationData/Item13_CollisionsBetStrikingVehVicVeh/party.csv' dbms=csv out=party replace;
getnames=yes;
run;
proc sort; by caseid;run;

* Merge with collisions 2011-2015;
DATA collisions; 
MERGE collisions (IN=In1) party(IN=In2); 
BY caseid; 
IF (In1=1 and In2=1) then output collisions; 
RUN; 
proc contents; run;
proc sort; by caseid; run;

* Label variable values;
PROC FORMAT;
VALUE $ FMTA
"A" = "Passenger Car/Station Wagon"
"B" = "Passenger Car with Trailer"
"C" = "Motorcycle/Scooter"
"D" = "Pickup or Panel Truck"
"E" = "Pickup or Panel Truck with Trailer"
"F" = "Truck or Truck Tractor"
"G" = "Truck or Truck Tractor with Trailer"
"H" = "School Bus"
"I" = "Other Bus"
"J" = "Emergency Vehicle"
"K" = "Highway Construction Equipment"
"L" = "Bicycle"
"M" = "Other Vehicle"
"N" = "Pedestrian"
"O" = "Moped"
;
VALUE $ FMTB
"A" = "Non-Collision"
"B" = "Pedestrian"
"C" = "Other Motor Vehicle"
"D" = "Motor Vehicle on Other Roadway"
"E" = "Parked Motor Vehicle"
"F" = "Train"
"G" = "Bicycle"
"H" = "Animal"
"I" = "Fixed Object"
"J" = "Other Object"
; 
VALUE $ FMTG
"A" = "Head-On"
"B" = "Sideswipe"
"C" = "Rear End"
"D" = "Broadside"
"E" = "Hit Object"
"F" = "Overturned"
"G" = "Vehicle/Pedestrian"
"H" = "Other"
;
data collisions;
 set collisions;

FORMAT
vehtype FMTA. involve FMTB. crashtyp FMTG. ;

* Recode vehicle type;
vehicle = .;

* truck, tractor, tractor trailer, emergency vehicle, highway equipment;
if (vehtype = 'F' or vehtype = 'G' or vehtype = 'J' or vehtype = 'K') then vehicle = 6;

* bus;
if (vehtype = 'H' or vehtype = 'I') then vehicle = 5;

* Car or pickup w or w/o a trailor or other motor vehicle;
if (vehtype = 'A' or vehtype = 'B' or vehtype = 'D' or vehtype = 'E' or vehtype = 'M') then vehicle = 4;

* Motor cycle or moped;
if (vehtype = 'C' or vehtype = 'O') then  vehicle = 3;

* bicycle;
if vehtype = 'L' then  vehicle = 2;

* pedestrian;
if vehtype = 'N' then  vehicle = 1;
run;

* Format recoded vehicle types;
proc format;
value FMTC 
0 = "Other"
1 = "Pedestrian"
2 = "Bicycle"
3 = "Motorcycle"
4 = "Car/Pick-up"
5 = "Bus"
6 = "Truck"
7 = "Train"
;

data collisions;
 set collisions;

FORMAT
vehicle FMTC.;

run;
proc contents;run;

* Select first record to get involved code;
proc sort;
  by caseid;
data first_involve;
  set collisions;
  by caseid;
  if first.caseid = 1;
run;

* Transpose file from long to wide;
proc transpose data= collisions out=collisions_wide prefix=parnum;
  by caseid;
  id parnum;
  var vehicle;
run;

* merge data sets on caseid to pick up involved field;
data collisions_involve;
  merge first_involve collisions_wide;
  by caseid;
run;

* Determine the striking vehicle by assigning precedence order;
* Train-7 > Truck-6 > Bus-5 > Car-4 > Motorcycle-3 > Bike-2 > Ped-1;

* Identify the largest vehicle among the first 5 parties;

data striking_vehicle (KEEP = caseid involve crashtyp parties par_sum parnum1 parnum2 parnum3 parnum4 parnum5 vstrike);
 set collisions_involve;
vstrike = parnum1;
if vstrike < parnum2 and parnum2 NE . then vstrike = parnum2;
if vstrike < parnum3 and parnum3 NE . then vstrike = parnum3;
if vstrike < parnum4 and parnum4 NE . then vstrike = parnum4;
if vstrike < parnum5 and parnum5 NE . then vstrike = parnum5;

* if any of the parties are blank then striking vehicle is blank;
* Corrected for victim file available info on train, ped and bicyclist;

par1 = 0;
par2 = 0;
par3 = 0;
par4 = 0;
par5 = 0;
if parnum1 NE . then par1 = 1 ;
if parnum2 NE . then par2 = 1 ;
if parnum3 NE . then par3 = 1 ;
if parnum4 NE . then par4 = 1 ;
if parnum5 NE . then par5 = 1 ;
par_sum = par1 + par2 + par3 + par4 + par5;
* if parties > par_sum then vstrike = .;
* If there are 6 or more parties, pick the largest in the first 5;
if parties > par_sum and parties LE 5 then vstrike = .;

format vstrike fmtc.; 
run;

proc sort;
by caseid;
run;

proc contents;run;

****  Read Victim Datafile and Keep only Fatal/Serious Injuries *******;
proc import datafile= '/folders/myfolders/myfolders/ITHIM/CalibrationData/Item13_CollisionsBetStrikingVehVicVeh/victim.csv' dbms=csv out=victim replace;
getnames=yes;
run;
proc contents; run;

proc format;
VALUE FMTA 1 = "Killed" 2 = "Severe Injury"  3 = "Other Visible Injury" 4 = "Complaint of Pain" 0 = "No Injury" ;
VALUE FMTB 1 = "Driver" 2 = "Passenger" 3 = "Pedestrian" 4 = "Bicyclist" 5 = "Other-non motor vehicle" 6 = "Non-injured party" ;

* Keep only fatal (1) and serious (2) injuries;
* vinjury is a numeric value (changed from original SAS input file);
data victim;
set victim (where =(vinjury = 1 or vinjury = 2));

FORMAT vinjury FMTA. vtype FMTB.; 
run;

proc sort; by caseid parnum;run;
proc contents; run;

proc format;
value $FMTC A = "Passenger Car" B = "Passenger Car & Trailer" C = "Motorcycle" D = "Pickup Truck" E = "Pickup Truck & Trailer"
F = "Truck or Truck Tractor" G = "Truck & Trailer" H = "Schoolbus" I = "Other Bus" J = "Emergency Vehicle" K = "Highway Construction Equipment"
L = "Bicycle" M = "Other Vehicle" N = "Pedestrian" O = "Moped";

*******  Read Party Datafile *******;
proc import datafile= '/folders/myfolders/myfolders/ITHIM/CalibrationData/Item13_CollisionsBetStrikingVehVicVeh/party.csv' dbms=csv out=party replace;
getnames=yes;
run;

data party;
set party;
FORMAT vehtype $FMTC. ; 
run; 
proc sort; by caseid parnum;run;
proc contents; run;


*******  Read Collisions Datafile *******;
proc import datafile= '/folders/myfolders/myfolders/ITHIM/CalibrationData/Item13_CollisionsBetStrikingVehVicVeh/collisions.csv' dbms=csv out=collisions replace;
getnames=yes;
run;

* data collisions for years 2011 to 2015;
data collisions; 
 set collisions (where=(year GE 2011 and year LE 2015));

run; 
proc sort; by caseid;run;
proc contents; run;

*********** Merge Victims with Party on CaseID and Party Number;
DATA inBOTH; 
MERGE victim (IN=In1) party(IN=In2); 
BY caseid parnum; 
IF (In1=1 and In2=1) then output inBOTH; 
RUN; 
proc contents; run;
proc sort; by caseid; run;


*********** Merge Victims and Party with Collisions on CaseID;
DATA injuries; 
MERGE inBOTH (IN=In1) collisions(IN=In2); 
BY caseid; 
IF (In1=1 and In2=1) then output injuries; 
RUN; 
proc sort; by caseid ;run;
proc contents; run;


* Link to file with geocoded roadway type;
proc import datafile= '/folders/myfolders/myfolders/ITHIM/CalibrationData/Item13_CollisionsBetStrikingVehVicVeh/Victims_serious_fatal_CA_collisions_2011-2015.csv' dbms=csv out=victims_fcc replace;
delimiter=",";
getnames=yes;
guessingrows=500;
run;

* Select first record to get fcc code of collision;
proc sort;
  by caseid;run;

* Convert numeric caseid to character to facilitate merge step);
data victims_fcc (keep = caseid rtyp_fcc roadway);
set victims_fcc;
*  by caseid;
*  if first.caseid = 1;
*  caseid_char = put(caseid,10.);
*  caseid_char = substr(caseid_char,2,9);
*  caseid_char = compbl(caseid_char);
run;

* rename character caseid ;
* data victims_fcc;
* set victims_fcc;
*   caseid= substr(caseid_char,2,9);
*   caseid = compbl(caseid);
* run;

* proc sort;
*   by caseid;run;

* Merge collisions with fcc code with injured victims file;
data injuries_fcc;
merge injuries victims_fcc;
by caseid;
run;


data victims (keep = caseid year county rtyp_fcc roadway parnum parties vehtype vehicle ptype vtype vinjury pedcol biccol mccol truckcol pedkill pedinj bickill bicinj mckill mcinjure);
 set injuries_fcc;

* Recode vehicle type of victim;
vehicle = .;

* truck, tractor, tractor trailor, emergency vehicle, highway equipment;
if (vehtype = 'F' or vehtype = 'G' or vehtype = 'J' or vehtype = 'K') then vehicle = 6;

* bus;
if (vehtype = 'H' or vehtype = 'I') then vehicle = 5;

* Car or pickup w or w/o a trailor or other motor vehicle;
if (vehtype = 'A' or vehtype = 'B' or vehtype = 'D' or vehtype = 'E' or vehtype = 'M') then vehicle = 4;

* Motor cycle or moped;
if (vehtype = 'C' or vehtype = 'O') then  vehicle = 3;

* bicycle;
if vehtype = 'L' then  vehicle = 2;

* pedestrian;
if vehtype = 'N' then  vehicle = 1;

* Missing data from vehicle and victim type;
* Pedestrian;
if (vehtype = '' or vehtype = '-') and vtype = 3 then vehicle = 1;
* Bicyclist;
if (vehtype = '' or vehtype = '-') and vtype = 4 then vehicle = 2;
run;

* Format recoded vehicle types;
proc format;
value FMTC 
0 = "Other"
1 = "Pedestrian"
2 = "Bicycle"
3 = "Motorcycle"
4 = "Car/Pick-up"
5 = "Bus"
6 = "Truck"
7 = "Train"
;
VALUE FMTD 1 = "Killed" 2 = "Severe Injury"  3 = "Other Visible Injury" 4 = "Complaint of Pain" 0 = "No Injury" 
;
data victims;
 set victims;

FORMAT
vehicle FMTC. vinjury FMTD. ;

* Sort the file by caseid;
proc sort;
 by caseid;
run;

* Merge the victims with the striking vehicle file;
data injury_matrix2015;
  merge striking_vehicle (IN = In1) victims (IN = In2);
  by caseid;
  IF (In1=1 and In2=1) then output injury_matrix2015; 
run;

* Create SAS data file ;
libname z '/folders/myfolders/myfolders/ITHIM/CalibrationData/Item13_CollisionsBetStrikingVehVicVeh/';
data z.injury_matrix2015;
   set injury_matrix2015;
run;

/* 
* end of commented out code;

* PART 2 is for statical tabulation of results;

************************** Read SAS data file****************** ;
LIBNAME switrs '/folders/myfolders/myfolders/ITHIM/CalibrationData/Item13_CollisionsBetStrikingVehVicVeh'; 
data injury_matrix2015;
 set switrs.injury_matrix2015;
run;
proc sort; by county; run;

* Read in County to MPO Lookup Table;
proc import datafile= '/folders/myfolders/myfolders/ITHIM/Crosswalks/CA_County_FIPS2Region2010.xls' dbms=xls out= CA_County_FIPS2Region2010 replace;
getnames=yes;
run;

data CA_County_FIPS2Region2010;
 set CA_County_FIPS2Region2010;
 county = upcase(countyname);
run;
proc sort; by county;run;

* Merge with injury file;
data injury_matrix2015;
 merge injury_matrix2015 CA_County_FIPS2Region2010;
 by county;
run;
proc contents;
title1 'SWITRS Road Traffic Injury Matrix, 2011-2015';
run;

proc freq ;
 tables megaregion_code;
run;

*** Beginning of loop1;
%macro loop1(relist);
%local i regroup;
%let i=1;
%let regroup=%scan(&relist,&i);
%do %while (&regroup ne);

* Assign the victim to the cell in the injury matrix;
data injury_matrix_mega&i (keep = county caseid involve crashtyp parties parnum1 parnum2 parnum3 parnum4 parnum5 vstrike vehicle a_ij vinjury roadway rtyp_fcc parnum par_sum ptype vehtype vtype two_vehtypes max2 megaregion_code Megaregion_name);
  set injury_matrix2015;
if megaregion_code = "&regroup";

* Correct for missing data on bicyclists and pedestrians;
* Pedestrians not recorded as a party;
if vstrike = . and (parties > par_sum) and (parnum1 NE . and parnum1 NE 1) and vehicle = 1 then vstrike = parnum1;
if vstrike = . and (parties > par_sum) and (parnum2 NE . and parnum2 NE 1) and vehicle = 1 then vstrike = parnum2;

* Bicyclists;
if vstrike = . and (parties > par_sum) and (parnum1 NE . and parnum1 NE 2) and vehicle = 2 then vstrike = parnum1;
if vstrike = . and (parties > par_sum) and (parnum2 NE . and parnum2 NE 2) and vehicle = 2 then vstrike = parnum2;

* Train as a striking vehicle;
if involve = 'F' then vstrike = 7;

* Identify the second largest vehicle among the first 5 parties;
* for 3 way collisions involving unique vehicle types;

* Identify 3-way collisions in first 5 parties involving at least 2 ;
* different types of vehicles;

if (parnum1 NE parnum2) and (parnum1 NE . AND parnum2 NE .) then p12 = 1;
if (parnum1 NE parnum3) and (parnum1 NE . AND parnum3 NE .) then p13 = 1;
if (parnum1 NE parnum4) and (parnum1 NE . AND parnum4 NE .) then p14 = 1;
if (parnum1 NE parnum5) and (parnum1 NE . AND parnum5 NE .) then p15 = 1;

if parties GE 3 and (p12 = 1 or p13=1 or p14=1 or p15 = 1) then two_vehtypes = 'TRUE';

* Identify the second largest vehicle which is not the striking vehicle;
* This may be the same type as the striking vehicle;

if parnum1 NE vstrike then max2 = parnum1;
if parnum1 =  vstrike then max2 = parnum2;
if parnum2 GE max2 and (parnum2 NE vstrike and parnum2 NE .) then max2 = parnum2;
if parnum3 GE max2 and (parnum3 NE vstrike and parnum3 NE .) then max2 = parnum3;
if parnum4 GE max2 and (parnum4 NE vstrike and parnum4 NE .) then max2 = parnum4;
if parnum5 GE max2 and (parnum5 NE vstrike and parnum5 NE .) then max2 = parnum5;

* Count the number of vehicles by type;
* Cars;
car1=0; car2=0; car3=0; car4=0; car5=0;
if parnum1 = 4 then car1 = 1;
if parnum2 = 4 then car2 = 1;
if parnum3 = 4 then car3 = 1;
if parnum4 = 4 then car4 = 1;
if parnum5 = 4 then car5 = 1;
car_count = car1 + car2 + car3 + car4 + car5;

* Buses;
bus1=0; bus2=0; bus3=0; bus4=0; bus5=0;
if parnum1 = 5 then bus1 = 1;
if parnum2 = 5 then bus2 = 1;
if parnum3 = 5 then bus3 = 1;
if parnum4 = 5 then bus4 = 1;
if parnum5 = 5 then bus5 = 1;
bus_count = bus1 + bus2 + bus3 + bus4 + bus5;

* Trucks;
truck1=0; truck2=0; truck3=0; truck4=0; truck5=0;
if parnum1 = 6 then truck1 = 1;
if parnum2 = 6 then truck2 = 1;
if parnum3 = 6 then truck3 = 1;
if parnum4 = 6 then truck4 = 1;
if parnum5 = 6 then truck5 = 1;
truck_count = truck1 + truck2 + truck3 + truck4 + truck5;

* Motorcycles;
motorcycle1=0; motorcycle2=0; motorcycle3=0; motorcycle4=0; motorcycle5=0;
if parnum1 = 3 then motorcycle1 = 1;
if parnum2 = 3 then motorcycle2 = 1;
if parnum3 = 3 then motorcycle3 = 1;
if parnum4 = 3 then motorcycle4 = 1;
if parnum5 = 3 then motorcycle5 = 1;
motorcycle_count = motorcycle1 + motorcycle2 + motorcycle3 + motorcycle4 + motorcycle5;

* If it is a 3+ party collision involving 2 or more vehicle types AND;
* the striking vehicle is the same as victim vehicle AND the collision;
* involves another vehicle of the same type THEN that other vehicle;
* is the striking vehicle, otherwise the next largest vehicle is the;
* striking vehicle;

* Truck;
if (parties GE 3) AND (two_vehtypes ='TRUE') AND (vstrike = 6 AND vehicle = 6) AND truck_count GE 2 then vstrike = 6;
if (parties GE 3) AND (two_vehtypes ='TRUE') AND (vstrike = 6 AND vehicle = 6) AND truck_count = 1 then vstrike = max2;

* Bus;
if (parties GE 3) AND (two_vehtypes ='TRUE') AND (vstrike = 5 AND vehicle = 5) AND bus_count GE 2 then vstrike = 5;
if (parties GE 3) AND (two_vehtypes ='TRUE') AND (vstrike = 5 AND vehicle = 5) AND bus_count = 1 then vstrike = max2;

* Car;
if (parties GE 3) AND (two_vehtypes ='TRUE') AND (vstrike = 4 AND vehicle = 4) AND car_count GE 2 then vstrike = 4;
if (parties GE 3) AND (two_vehtypes ='TRUE') AND (vstrike = 4 AND vehicle = 4) AND car_count = 1 then vstrike = max2;

* Motor Cycle;
if (parties GE 3) AND (two_vehtypes ='TRUE') AND (vstrike = 3 AND vehicle = 3) AND car_count GE 2 then vstrike = 3;
if (parties GE 3) AND (two_vehtypes ='TRUE') AND (vstrike = 3 AND vehicle = 3) AND motorcycle_count = 1 then vstrike = max2;

* Correct ped x ped (11) in which striking vehicle not recorded;
if vstrike=1 and vehicle = 1 then vstrike = .;

* Correct bicycle x ped collision with injured bicyclist (21) ;
* misclassified as bicycle x bicycle collision (22);
if parties = 2 and vstrike=2 and vehicle = 2 and (parnum1 = 1 or parnum2 = 1) then vstrike = 1;

* Assign the cell in the risk matrix;
a_i = put(vehicle,1.0);
a_j = put(vstrike,1.0);
if a_i = "" then a_i=".";
if a_j = "" then a_j=".";
a_ij = a_i||a_j;
run;

* proc contents;
* run;

********* Calculate victims in which no other vehicle was involved ****;
data only_one_party&i;
 set injury_matrix_mega&i;
  if parties = 1;
run;

proc sort;
 by vinjury roadway;
run;

* Count the victims, roadway, and severity in one party collisions;
proc freq;
title1 'SWITRS Road Traffic Injury Matrix, 2006-2010';
title2 'One Party Collisions - No Other Vehicle';
title3 "Mega-region code 0&i ";
   tables vinjury / nopercent nocol norow missing;
   tables roadway / nopercent nocol norow missing;
   tables vehicle / nopercent nocol norow missing;
run;
proc freq;
title1 'One Party Collisions - No Other Vehicle by Severity and Roadway';
title2 "Mega-region code 0&i ";

* class vinjury roadway;
BY vinjury roadway;
  tables vehicle / nopercent nocol norow missing; 
OUTPUT OUT=ONEPARTY_0&i;
run;

*****************  Two and Higher Party Collisions ********************;

data two_party_higher_victims&i;
  set injury_matrix_mega&i;
  if parties GE 2;
run;

proc sort;
 by vinjury roadway;
run;

proc freq;
title1 'Two and Higher Party Collisions';
title2 "Mega-region code 0&i ";

 tables a_ij / missing; 
run;

* Count the victims, roadway, and severity in 2+ party collisions;
proc freq;
title1 'Two Party Collisions';
title2 "Mega-region code 0&i ";

   tables vinjury / nopercent nocol norow missing;
   tables roadway / nopercent nocol norow missing;
   tables a_ij    / nopercent nocol norow missing;
run;
proc freq;
title1 'Two Party Collisions by Severity and Roadway';
title2 "Mega-region code 0&i ";

by vinjury roadway;
   tables a_ij    / nopercent nocol norow missing;
run;

%let i=%eval(&i+1);
%let regroup=%scan(&relist,&i);
%end;
%mend loop1;
%loop1(01 02 03 04 05 06 07);
*/
