* item13_rti_matrix8-4-19.sas - N Maizlish;
* Program that imputes missing data from a 8 by 9 matrix of ;
* road traffic injuries including missing data and transposes rows of;
* 8 by 9 matrices as a 1 x 9 vector that simulates the structure ;
* of the ITHIM calibration sheet, whose strata field is made up ; 
* of the roadway-vinjury and mode is the pairwise collision type;
* Program incorporates looping for 3 (made up), 6 vinjury-roadway type;

* Read control matrix to structure injuries;
proc import datafile= '/folders/myfolders/myfolders/ITHIM/CalibrationData/Item13_CollisionsBetStrikingVehVicVeh/control_matrix_56_char.csv' dbms=CSV out=control_matrix replace;  
proc sort data = control_matrix; by typology ; run;

* Read SWITRS SAS injury file;
libname switrs '/folders/myfolders/myfolders/ITHIM/CalibrationData/Item13_CollisionsBetStrikingVehVicVeh';    

* Read county to Megaregion look up table; 
proc import datafile= '/folders/myfolders/myfolders/ITHIM/Crosswalks/CA_County_FIPS2Region2010.xls' dbms=XLS out=counties replace;

proc contents; run;

* Rename link county field;
data counties;
set counties;
Countyname=upcase(countyname);
rename Countyname = county;
keep countyname mpo_name region_code region_name megaregion_name megaregion_code; 

proc sort; by county ; run;

* merge injury matrix to county-megaregion lookup table;
data  injury_matrix2015; set switrs.injury_matrix2015;
person_id= _n_ ; 
run;
proc sort; by county ; run;


data injury_matrix2015; 
merge injury_matrix2015 counties; 
by county;   
* striking vehicle; 
* 1=ped 2=bike 3=motorcycle 4=car 5=bus 6=truck 7=NOV;
* victim vehicle; 
* 1=ped 2=bike 3=motorcycle 4=car 5=bus 6=truck ;


* Assign the pairwise striking vehicle-victim cell in the risk matrix;
a_i = put(vehicle,1.0);
a_j = put(vstrike,1.0);
if a_i = "" then a_i=".";
if a_j = "" then a_j=".";
if parties = 1 then a_j= "7";
typology = a_i||a_j;

* recoding missing typology;
if typology = "1." then typology = "19" ; else if typology = "2." then typology = "29"; else if
typology = "3." then typology = "39" ; else if typology = "4." then typology = "49" ; else if
typology = "5." then typology = "59" ; else if typology = "6." then typology = "69" ; else if
typology = ".1" then typology = "91" ; else if
typology = ".2" then typology = "92" ; else if typology = ".3" then typology = "93" ; else if
typology = ".4" then typology = "94" ; else if
typology = ".5" then typology = "95" ; else if typology = ".6" then typology = "96" ; else if
typology = ".." then typology = "99" ; else if typology = ".7" then typology = "97"; 

* set roadway strata; 
if roadway = "interst" then rdway = 1;
if roadway = "arteria" then rdway = 2;
if roadway = "local" then rdway = 3;

* set roadway and severity strata;
if vinjury = 1 AND rdway = 1 then strata_code = "HWYKILL";
if vinjury = 2 AND rdway = 1 then strata_code = "HWYSEV";
if vinjury = 1 AND rdway = 2 then strata_code = "ARTKILL";
if vinjury = 2 AND rdway = 2 then strata_code = "ARTSEV";
if vinjury = 1 AND rdway = 3 then strata_code = "LOCKILL";
if vinjury = 2 AND rdway = 3 then strata_code = "LOCSEV";

* Storage type conversion to numeric to match control matrix;
type1 = input (typology, 3.);
drop typology ;
rename type1 = typology;

run;
 
proc contents; run;

* Run this segment to calcuate the inflation factor; 
* due to unknown facility type; 
proc freq;
 tables megaregion_code*strata_code/ missing;
 run;

*********************** loop1 - Geography *****************;
 %macro loop1(geolist);
%local k geogroup ;
%let k=1;
%let geogroup=%scan(&geolist,&k);
%do %while (&geogroup ne); 

* Select 1 geography;
data rti_geo&geogroup;
  set injury_matrix2015;
  if megaregion_code = "&geogroup"; 
run;

* Select a Roadway Type- RTI vinjury combination; 
data rti_geo&geogroup; 
 set rti_geo&geogroup;
run;

*********************** loop2 - Roadway Type- RTI vinjury *****************;

%macro loop2(stratalist);
%local i stratagroup ;
%let i=1;
%let stratagroup=%scan(&stratalist,&i);
%do %while (&stratagroup ne);

* Subset a roadway-vinjury strata;
data rti_strata;
 set rti_geo&geogroup;
 if strata_code = "&stratagroup";
 run;
proc contents; run;

* Aggregate RTIs by typology of Victim-Striking Vehicle modes;
proc sort data= rti_strata; by typology ; run;
PROC MEANS noprint data=rti_strata;
BY typology ;
VAR person_id;
output out=rti_long n(person_id)=freq;
run;

* add control matrix ;
data rti_long (keep=typology freq);
  set rti_long control_matrix ;
run;

* Re-aggregate RTIs by typology of Victim-Striking Vehicle modes;
proc sort data= rti_long; by typology ; run;
PROC MEANS noprint data=rti_long;
BY typology ;
VAR freq;
output out=rti_long sum(freq)=rti;
run;

proc sort data= rti_long; by typology ; run;
proc sort data= control_matrix; by typology ; run;

* Merge back to pick up victim and striking vehicle indices;
data rti_long (keep=vstrike vehicle typology rti);
merge rti_long control_matrix;
by typology ;
run;
proc sort data=rti_long; by vehicle; run;

* Transpose to get into matrix format;
proc transpose data=rti_long
out=rti_long_transp_id_by
name=rti;
by vehicle;
id vstrike;
run;

* Keep only rti rows and calculate victim total;
data rti_long_transp_id_by;
 set rti_long_transp_id_by; 
 if rti = "rti";
 vtotal = s1 + s2 + s3 + s4 + s5 + s6 + s7 + sm;
 run;

* Calculate striking column totals;
PROC MEANS noprint data=rti_long_transp_id_by;
VAR s1 s2 s3 s4 s5 s6 s7 sm vtotal;
output out=stotal sum(s1)=s1 sum(s2)=s2 sum(s3)=s3 sum(s4)=s4 sum(s5)=s5 sum(s6)=s6 sum(s7)=s7 sum(sm)=sm sum(vtotal)=vtotal ;
run;

* add total row to rest of matrix;
data rti_long_transp_id_by;
 set rti_long_transp_id_by stotal;
 run;
proc contents;run;

* Read data into IML ;
proc iml;
use rti_long_transp_id_by;
read all ;

* combine x0 x1 x2 into a matrix X ;
RTI = S1 || S2 || S3 || S4 || S5 || S6 || S7 || SM || vtotal;
vehicle = {"V1", "V2", "V3", "V4", "V5", "V6",       "VM", "Total"};
vstrike = {"S1"  "S2"  "S3"  "S4"  "S5"  "S6"  "S7"  "SM"  "Total"};	
print RTI [colname = vstrike rowname=vehicle label = "RTI Matrix"];

* Calculate imputed values for missing data;
newrti = repeat({0}, 8, 9);
* i = rows and j = columns;
do i = 1 to 6;
do j = 1 to 7;
* newrti[i,j] = (rti[i,j]);
*              (H13+     ((H13/       ($J13   -$I13)   *$I13)    +(H13/      (H$17   - H$16)   *H$16)))    *($J$17   /($J$17   -$I$16));
newrti[i,j] = (rti[i,j] +((rti[i,j]/(rti[i,9]-rti[i,8])*rti[i,8])+(rti[i,j]/(rti[8,j]-rti[7,j])*rti[7,j])))*(rti[8,9]/(rti[8,9]-rti[7,8]));
end;
end;

* Replace division by 0 with 0;
do i = 1 to 6;
do j = 1 to 7;
if newrti[i,j] = . then newrti[i,j] = 0;
end;
end;
print newrti [colname = vstrike rowname=vehicle label = "Imputed RTI Matrix  &geogroup &stratagroup"];

* Create new matrix withour totals for export;
imputedrti = repeat({0}, 6, 7);
do i = 1 to 6;
do j = 1 to 7;
   imputedrti[i,j] = newrti[i,j] ;
end;
end;
print imputedrti [colname = vstrike rowname=vehicle label = "Imputed RTI Matrix  &geogroup &stratagroup"];

* writie out RTI matrix as a data set;
create rti_output var {s1 s2 s3 s4 s5 s6 s7} ;
append from imputedrti;

%macro loop3(rowlist);
%local i rowcount;
%let i=1;
%let rowcount=%scan(&rowlist,&i);
%do %while (&rowcount ne);

* Transpose file one row at a time;
data matrix_row&i (keep= S1 S2 s3 s4 s5 s6 s7 );
 set rti_output;
 if _n_ = &rowcount;
run;

proc transpose data=matrix_row&rowcount
out=matrix_transposed_col&rowcount;
run;

* Rename column heads and add victim id;
* Mode_code_char is character and mode_code is numeric;
data matrix_transposed_col&rowcount;
 set matrix_transposed_col&rowcount (rename= (_NAME_ = typology  col1=rti));
  mode_code_char = "V" || "&rowcount" || typology;
run;

%let i=%eval(&i+1);
%let rowcount=%scan(&rowlist,&i);
%end;
%mend loop3;
%loop3(1 2 3 4 5 6);

* append all the columns within a strata;
data matrix1by7_&stratagroup (keep= rti strata_code mode_code_char geotype_code);
 set matrix_transposed_col1 matrix_transposed_col2 matrix_transposed_col3 matrix_transposed_col4 matrix_transposed_col5 
matrix_transposed_col6 ;
 strata_code = "&stratagroup";
 geotype_code = "&geogroup";
run;

%let i=%eval(&i+1);
%let stratagroup=%scan(&stratalist,&i);
%end;
%mend loop2;
%loop2(HWYKILL HWYSEV ARTKILL ARTSEV LOCKILL LOCSEV);

* append all the strata into a single file for one geography;
data matrix1by7_total_geo&geogroup;
set matrix1by7_HWYKILL matrix1by7_HWYSEV matrix1by7_ARTKILL matrix1by7_ARTSEV matrix1by7_LOCKILL matrix1by7_LOCSEV;
run;

%let k=%eval(&k+1);
%let geogroup=%scan(&geolist,&k);
%end;
%mend loop1;
%loop1( 01 02 03 04 05 06 07) 

* append individual geography files into one file and put in standard ITHIM format;
* Note to create annual number divide by 5;
data matrix1by7_total_geography;
format geotype_name $CHAR20.0 modestrike $CHAR10.0 modevictim $CHAR10.0 mode $CHAR25.0 ;
set  matrix1by7_TOTAL_geo0: ;

* Inflate values to account for missing roadway in SWITRS files;
* 01 - San Diego; 
if geotype_code = "01" then rti = rti*1.07973903588257;
* 02 - Southern California; 
if geotype_code = "02" then rti = rti*1.06845672406525;
* 03 - Central Coast; 
if geotype_code = "03" then rti = rti*1.0;
* 04 - San Joaquin Valley; 
if geotype_code = "04" then rti = rti*1.10362364907819;
* 05 - Bay Area; 
if geotype_code = "05" then rti = rti*1.08315334773218;
* 06 - Sacramento Area; 
if geotype_code = "06" then rti = rti*1.08459337964855;
* 07 - Other; 
if geotype_code = "07" then rti = rti*1.0;

* Divide by 5 to get annualized number;
 item_result = rti/5;
 
 scenario_id = 1;
 item_id = 13;
 Item_name = "5-year annual average number of road traffic injuries";
 units = "number";
 urbrur = 1;
 report_year = "2011-2015";
 age_group = "All Ages";
 strata = strata_code;
 strata_type = "Facility Type-Injury Severity";
if substr(mode_code_char,2,1) = "1" then modevictim = "Ped";
if substr(mode_code_char,2,1) = "2" then modevictim = "Bike";
if substr(mode_code_char,2,1) = "3" then modevictim = "Motorcycle";
if substr(mode_code_char,2,1) = "4" then modevictim = "Car";
if substr(mode_code_char,2,1) = "5" then modevictim = "Bus";
if substr(mode_code_char,2,1) = "6" then modevictim = "Truck";
if substr(mode_code_char,4,1) = "1" then modestrike = "Ped";
if substr(mode_code_char,4,1) = "2" then modestrike = "Bike";
if substr(mode_code_char,4,1) = "3" then modestrike = "Motorcycle";
if substr(mode_code_char,4,1) = "4" then modestrike = "Car";
if substr(mode_code_char,4,1) = "5" then modestrike = "Bus";
if substr(mode_code_char,4,1) = "6" then modestrike = "Truck";
if substr(mode_code_char,4,1) = "7" then modestrike = "NOV";
prefixvictim = "V-";
prefixstrike = "S-";
slash = "/";
mode = cat(prefixvictim,trim(modevictim),slash,prefixstrike,trim(modestrike));
mode_n = substr(mode_code_char,2,1) || substr(mode_code_char,4,1);
* mode_code is a numeric field;
mode_code = input(mode_n,2.0);

* Assign Megaregion name;
geotype="megaregion";
if geotype_code = "01" then geotype_name = "San Diego";
if geotype_code = "02" then geotype_name = "Southern California";
if geotype_code = "03" then geotype_name = "Central Coast";
if geotype_code = "04" then geotype_name = "San Joaquin Valley";
if geotype_code = "05" then geotype_name = "Bay Area";
if geotype_code = "06" then geotype_name = "Sacramento Area";
if geotype_code = "07" then geotype_name = "Other";

unwt_N = .;
wt_N = .;
sex ="";
se = .;
cv = .;
date = DATETIME();
format date datetime16.0;
run;

data item13_rti_matrix (drop=rti prefixvictim prefixstrike slash modestrike modevictim megaregion_code mode_code_char mode_n);
retain scenario_id item_id item_name units urbrur report_year geotype geotype_name geotype_code mode mode_code strata_type strata strata_code age_group sex unwt_N wt_N item_result se cv date ;
set matrix1by7_total_geography;
run;

* Sort file for export;
proc sort; by geotype geotype_name ; run;

* Export Megaregion as XLS file;
proc export data= item13_rti_matrix outfile='/folders/myfolders/myfolders/ITHIM/CalibrationData/Item13_CollisionsBetStrikingVehVicVeh/Item13rti_matrix2019-08-04.xlsx' dbms=XLSX replace;
run;

