* Item6_Age_sex_mortality_rates5-26-13.sas  N Maizlish 5-26-13;
* Reads SDMF 2009-2011 files and creates mortality rates for ITHIM;
* Calibration for California Counties;



* Read County to Region Look-up Table;
proc import datafile= 'T:\ITHIM\Crosswalks\CA_County_FIPS2Region2010.xlsx' dbms=xlsx out= CA_County_FIPS2Region2010 replace;
getnames=yes;
run;
proc sort; by county_fips;run;

* Read County Code look-up table;
proc import datafile= 'H:\SDMF\sdmf_county_code.xls' dbms=xls out= sdmf_county_code replace;
getnames=yes;
run;
proc sort; by county; run; 

* Read California Population Denominator data;
proc import datafile= 'T:\ITHIM\2010Census\item5pop_age_sex2010.xlsx' dbms=xlsx out= item5pop_age_sex2010 replace;
getnames=yes;
run;

* Keep county population data;
data item5pop_age_sex2010 (keep = geotype_code county_fips age_cat sex unwt_n);
 set item5pop_age_sex2010; 
  if geotype = "CO";
run;
proc sort; by county_fips sex age_cat; run;

* Read US Mortality Data;
proc import datafile= 'T:\ITHIM\2010Census\GBD_ITHIM_ProjDeathRate2010causes.xlsx' dbms=xlsx out= gbdus2010 replace;
getnames=yes;
run;

* Create mortality rate for U.S. 2010;
data gbdus2010;
 set gbdus2010;
death_rate_us = 100000*dproj/pproj;
run;
proc sort; by gbdcode sex age_cat; run; 

* Read Death File;
* 2009;

DATA deaths2009;
INFILE 'H:\SDMF\2009\D09NOID.dat' LRECL=400;
INPUT
#1
 @058 DOD                 8. /* Date of Death CCYYMMDD */
 @066 SEX                 1. /* 1=M 2=F */
 @069 DOB                 8. /* Date of Death CCYYMMDD */
 @156 COUNTY        $CHAR03. /* County code of residence */
 @161 COD           $CHAR05. /* ICD10 Cause of Death */
;

* Read Death File;
* 2010;

DATA deaths2010;
INFILE 'H:\SDMF\2010\D10NOID.dat' LRECL=400;
INPUT
#1
 @058 DOD                 8. /* Date of Death CCYYMMDD */
 @066 SEX                 1. /* 1=M 2=F */
 @069 DOB                 8. /* Date of Death CCYYMMDD */
 @156 COUNTY        $CHAR03. /* County code of residence */
 @161 COD           $CHAR05. /* ICD10 Cause of Death */
;

* Read Death File;
* 2011;

DATA deaths2011;
INFILE 'H:\SDMF\2011\DSMF11_NOPI.dat' LRECL=400;
INPUT
#1
 @058 DOD                 8. /* Date of Death CCYYMMDD */
 @066 SEX                 1. /* 1=M 2=F */
 @069 DOB                 8. /* Date of Death CCYYMMDD */
 @156 COUNTY        $CHAR03. /* County code of residence */
 @161 COD           $CHAR05. /* ICD10 Cause of Death */
;

data deaths09_11;
 set deaths2009 deaths2010 deaths2011;

* Create age categories;
DOBjulian = input
( put (DOB, Z8.) , yymmdd8.);
 DODjulian = input
( put (DOD, Z8.) , yymmdd8.);
format DOBjulian DODjulian mmddyy10.;
age = int((DODjulian - DOBjulian)/365.25);

* Create age categories for ITHIM;
if (age>=0  AND age<=4)  then age_cat = 0;
if (age>=5  AND age<=14) then age_cat = 5;
if (age>=15 AND age<=29) then age_cat = 15;
if (age>=30 AND age<=44) then age_cat = 30;
if (age>=45 AND age<=59) then age_cat = 45;
if (age>=60 AND age<=69) then age_cat = 60;
if (age>=70 AND age<=79) then age_cat = 70;
if (age>=80) then age_cat = 80;

run;
Proc contents; run;

proc sort; by county; run; 

* Merge with County Names and FIPS codes;
data deaths09_11; 
 merge deaths09_11 sdmf_county_code;
by county;
Run;

* Create Cause specific Mortality categories for ITHIM;

data deaths09_11;
  set deaths09_11;

icd10chr3 = trim(substr(cod,1,3));

* Colon and rectum cancers;
if icd10chr3 GE "C18" AND icd10chr3 LE "C21" then gbdcode = "U064";

* Breast Cancer;
if icd10chr3 EQ "C50"                        then gbdcode = "U069";

*  Hypertensive heart disease; 
if icd10chr3 GE "I10" AND icd10chr3 LE "I13" then gbdcode = "U106";

* Ischemic heart disease;
if icd10chr3 GE "I20" AND icd10chr3 LE "I25" then gbdcode = "U107";

* Cerebrovascular disease;
if icd10chr3 GE "I60" AND icd10chr3 LE "I69" then gbdcode = "U108";

* Alzheimer and other dementias;
if icd10chr3 in("F01","F03") OR (icd10chr3 GE "G30" and icd10chr3 LE "G31") then gbdcode = "U087";

* Diabetes; 
if icd10chr3 GE "E10" AND icd10chr3 LE "E14" then gbdcode = "U079";

* Depression; 
if icd10chr3 GE "F32" AND icd10chr3 LE "F33" then gbdcode = "U082";

* Road Injuries;
if (icd10chr3 GE "V01" AND icd10chr3 LE "V89") OR icd10chr3 EQ "Y85" then gbdcode = "U150";

* Inflammatory Heart Disease;
if icd10chr3 GE "I30" AND icd10chr3 LE "I33" OR (icd10chr3 in("I38","I40","I42")) then gbdcode = "U109";

* Respiratory Diseases;
if (icd10chr3 GE "J10" AND icd10chr3 LE "J18") OR (icd10chr3 GE "J20" AND icd10chr3 LE "J22") or (icd10chr3 GE "J00" AND icd10chr3 LE "J06") OR (icd10chr3 GE "J40" and icd10chr3 < "J44") or (icd10chr3 GE "J45" and icd10chr3 <"J46") or (icd10chr3 GE "J30" and icd10chr3 LE "J39") or (icd10chr3 GE "J47" and icd10chr3 LE "J98") then gbdcode = "U112";

* Lung Cancer;
if icd10chr3 GE "C33" AND icd10chr3 LE "C34" then gbdcode = "U067";

* Acute Respiratory Infections;
if age < 5 AND ((icd10chr3 GE "J10" AND icd10chr3 LE "J18") OR (icd10chr3 GE "J20" AND icd10chr3 LE "J22") or (icd10chr3 GE "J00" AND icd10chr3 LE "J06")) then gbdcode = "U039";
run;

proc sort; by county_fips sex age_cat; run;

* Aggregate Age-sex cells by county for all causes mortality;
proc means data= deaths09_11 noprint;
 by county_fips sex age_cat;
 var DOD;
output out = allcause_co_age_sex_deaths  N(dod) = deaths09_11;
run;

* Drop records with missing FIPS, age, or sex data;
data allcause_co_age_sex_deaths (drop = _type_ _freq_) ;
  set allcause_co_age_sex_deaths ;
 if county_fips NE "" AND age_cat NE . AND sex NE .;
gbdcode = "U999";
run;

proc sort data= deaths09_11; by county_fips gbdcode sex age_cat;run;


* Aggregate Age-sex cells by county for cause-specific mortality;
proc means data= deaths09_11 noprint;
 by county_fips gbdcode sex age_cat;
 var DOD;
output out = gbdcause_co_age_sex_deaths  N(dod) = deaths09_11;
run;

* Drop records with missing FIPS, age, or sex data;
data gbdcause_co_age_sex_deaths (drop = _type_ _freq_) ;
 set gbdcause_co_age_sex_deaths ;
 if gbdcode NE "" AND county_fips NE "" AND age_cat NE . AND sex NE .;
run;

* Concatenate files and annualize number of deaths;
data gbdcause_co_age_sex_deaths;
 set gbdcause_co_age_sex_deaths allcause_co_age_sex_deaths;
 deaths09_11= deaths09_11/3;

run;
proc contents;run;

* Looping Macro for each cause;
%macro loop1(causelist);
%local i causegroup;
%let i=1;
%let causegroup=%scan(&causelist,&i);
%do %while (&causegroup ne);

data gbd_&causegroup;
 set gbdcause_co_age_sex_deaths;
 if gbdcode = "&causegroup";
run;

proc sort; by county_fips sex age_cat;run;

* Merge with denominator file and replace missing deaths with 0;
data gbd_&causegroup;
merge item5pop_age_sex2010 gbd_&causegroup;
  by county_fips sex age_cat;
 if deaths09_11 = . then deaths09_11 = 0;
 if gbdcode = "" then gbdcode = "&causegroup";
run;

%let i=%eval(&i+1);
%let causegroup=%scan(&causelist,&i);
%end;
%mend loop1;
%loop1(U069 U064 U106 U107 U108 U087 U079 U082 U067 U109 U112 U039 U150 U999);

* Concatenate all the files;
data gbdcause_co_age_sex_death_rate;
 set GBD_U069 GBD_U064 GBD_U106 GBD_U107 GBD_U108 GBD_U087 GBD_U079 GBD_U082 GBD_U067 GBD_U109 GBD_U112 GBD_U150 GBD_U039 GBD_U999;

death_rate_ca = 100000*deaths09_11/unwt_n;
run;
proc sort; by gbdcode sex age_cat; run;

* Merge California county death rates with US rates;
data us_ca_co_age_sex_death_rate;
 merge gbdcause_co_age_sex_death_rate gbdus2010;
by gbdcode sex age_cat;
if (gbdcode NE "U039" and age_cat GE 0) OR (gbdcode EQ "U039" and age_cat < 5) ;
RR = 1;
if deaths09_11 >10 then RR = death_rate_ca/death_rate_us;
run;
proc sort; by gbdcode county_fips sex age_cat; run;

******************* Regional aggregation;
Proc sort data = gbdcause_co_age_sex_death_rate; by county_fips; run;

data us_ca_re_age_sex_death_rate;
 merge gbdcause_co_age_sex_death_rate CA_County_FIPS2Region2010;
 by county_fips;
run;

*********************BEGIN MPO ANALYSIS **********************;

******** Aggregate deaths and population over GEOGRAPHY;

* Read Region Look-up Table;
proc import datafile= 'T:\ITHIM\Crosswalks\CA_mpo2010.xls' dbms=xls out= CA_mpo2010 replace;
getnames=yes;
run;
proc sort; by mpo_code;run;


proc sort data= us_ca_re_age_sex_death_rate; by mpo_code gbdcode sex age_cat;run;


* Aggregate Age-sex cells by county for cause-specific mortality;
proc means data= us_ca_re_age_sex_death_rate noprint;
 by mpo_code gbdcode sex age_cat;
 var deaths09_11 unwt_N;
output out = mpo_age_sex_deaths  sum(deaths09_11)= deaths09_11 sum(unwt_N)= unwt_N;
run;

* Merge back to pick up US Rates and region name;

proc sort; by gbdcode sex age_cat; run;
* Merge California county death rates with US rates;
data us_mpo_age_sex_death_rate (drop = _type_ _freq_);
 merge mpo_age_sex_deaths gbdus2010;
by gbdcode sex age_cat;
if (gbdcode NE "U039" and age_cat GE 0) OR (gbdcode EQ "U039" and age_cat < 5) ;
death_rate_ca = 100000*deaths09_11/unwt_n;
RR = 1;
if deaths09_11 >10 then RR = death_rate_ca/death_rate_us;
run;
proc sort; by mpo_code;run;

data us_mpo_age_sex_death_rate (rename = (mpo_name=geotype_code mpo_code = geocode cause=modestrata gbdcode= modestrata_code age_cat=age_group sex=gender death_rate_ca=numerator death_rate_us=denominator RR=item_result));

merge us_mpo_age_sex_death_rate CA_mpo2010;
by mpo_code;
geotype = "mpo";
run;
Proc contents;run;

*********************END MPO ANALYSIS **********************;



*********************BEGIN MEGAREGION ANALYSIS **********************;

******** Aggregate deaths and population over GEOGRAPHY;

* Read Region Look-up Table;
proc import datafile= 'T:\ITHIM\Crosswalks\CA_megaregion2010.xls' dbms=xls out= CA_megaregion2010 replace;
getnames=yes;
run;
proc sort; by megaregion_code;run;


proc sort data= us_ca_re_age_sex_death_rate; by megaregion_code gbdcode sex age_cat;run;


* Aggregate Age-sex cells by county for cause-specific mortality;
proc means data= us_ca_re_age_sex_death_rate noprint;
 by megaregion_code gbdcode sex age_cat;
 var deaths09_11 unwt_N;
output out = megaregion_age_sex_deaths  sum(deaths09_11)= deaths09_11 sum(unwt_N)= unwt_N;
run;

* Merge back to pick up US Rates and region name;

proc sort; by gbdcode sex age_cat; run;
* Merge California county death rates with US rates;
data us_megaregion_age_sex_death_rate (drop = _type_ _freq_);
 merge megaregion_age_sex_deaths gbdus2010;
by gbdcode sex age_cat;
if (gbdcode NE "U039" and age_cat GE 0) OR (gbdcode EQ "U039" and age_cat < 5) ;
death_rate_ca = 100000*deaths09_11/unwt_n;
RR = 1;
if deaths09_11 >10 then RR = death_rate_ca/death_rate_us;
run;
proc sort; by megaregion_code;run;

data us_megaregion_age_sex_death_rate (rename = (megaregion_name=geotype_code megaregion_code = geocode cause=modestrata gbdcode= modestrata_code age_cat=age_group sex=gender death_rate_ca=numerator death_rate_us=denominator RR=item_result));

merge us_megaregion_age_sex_death_rate CA_megaregion2010;
by megaregion_code;
geotype = "megaregion";
run;
Proc contents;run;

*********************END MEGAREGION ANALYSIS **********************;



* Rename variables in County file;
data us_ca_co_age_sex_death_rate (rename=(countyname=geotype_code county_fips = geocode cause=modestrata gbdcode= modestrata_code age_cat=age_group sex=gender death_rate_ca=numerator death_rate_us=denominator RR=item_result));
 set us_ca_co_age_sex_death_rate;
geotype="county";
run;

* reformat for item6 export;
data item6 (drop = pproj dproj unwt_N deaths09_11 age_group gender rename=(geotype_code=geotype_name modestrata=strata modestrata_code=strata_code));
retain scenario_id item_id item_name units urbrur report_year geotype geotype_name geocode strata_type strata strata_code age_group sex numerator denominator item_result se cv version ;

format geotype $CHAR30.;
format geotype_code $CHAR30.;

 set us_ca_co_age_sex_death_rate us_megaregion_age_sex_death_rate us_mpo_age_sex_death_rate;

 scenario_id=1;
 item_id = 6;
 Item_name  = "Age-sex specific ratio of disease-specific mortality rate between geographic area and United States";
 units = "Dimensionless";
 urbrur = 1;
 report_year = "2009-2011"; 
 strata_type="death cause";
 se=.;
 cv=.;
 version = DATETIME();
 format version datetime16.0;
 if age_group=0  then age_group_inter = '00-04';
 if age_group=5  then age_group_inter = '05-14';
 if age_group=15 then age_group_inter = '15-29';
 if age_group=30 then age_group_inter = '30-44';
 if age_group=45 then age_group_inter = '45-59';
 if age_group=60 then age_group_inter = '60-69';
 if age_group=70 then age_group_inter = '70-79';
 if age_group=80 then age_group_inter = '80+'; 
 if gender   = 1 then sex='m';
 if gender   = 2 then sex='f';
 run;

data item6 (rename=(age_group_inter=age_group geocode=geotype_code));
set item6;
run;

data item6;
retain scenario_id item_id item_name units urbrur report_year geotype geotype_name geotype_code strata_type strata strata_code age_group sex numerator denominator item_result se cv version;
set item6;
run;



* Sort file for export;
proc sort; by geotype geotype_name strata sex age_group; run;

* Export County and region as CSV file;
proc export data= item6 outfile='T:\ITHIM\Outputs\ITHIM_item6mpo_co.csv' dbms=CSV replace;
run;

* Export County and region file as xlsx file;
proc export data= item6 outfile='T:\ITHIM\Outputs\ITHIM_item6mpo_co.xls' dbms=xls replace;
run;


